@@ -1,5 +1,5 @@
 # Netsink - Network Sinkhole for Isolated Malware Analysis
-# Copyright (C) 2013 Steve Henderson
+# Copyright (C) 2014 Steve Henderson
 # 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,10 +23,13 @@ import re
 
 from netsink import get_data_file
 from netsink.listener import StreamHandler
+from netsink.version import __version__
 
 class HTTPHandler(StreamHandler):
     """Basic HTTP support.  Serves up static content as specified in conf file.
     """
+    version = __version__
+    
     @staticmethod
     def match(data):
         return re.match(r'(GET|POST|PUT|DELETE|HEAD|OPTIONS|CONNECT|TRACE) \S+ HTTP/1\.[01]\r\n', data)
@@ -56,19 +59,23 @@ class HTTPHandler(StreamHandler):
                 break
         
         # read (and ignore) any body
-        m = re.match("Content-Length: (?P<length>\d+)", data)
+        m = re.search("Content-Length: (?P<length>\d+)\r\n", data)
         if m:
             self.rfile.read(int(m.group('length')))
         # handle request
+        host = ""
+        m = re.search(r"Host: (?P<host>[0-9a-zA-Z\-\.\:]+)\r\n", data)
+        if m:
+            host = m.group('host').lower() # normalise
         m = re.match(r"^(?P<method>\w+) (?P<path>\S+) (?P<version>HTTP/\d\.\d)\r\n", data)
         if m:
-            self.handlepath(m.group('method'), m.group('path'))
+            self.handlepath(host, m.group('method'), m.group('path'))
             
-    def handlepath(self, method, path):
+    def handlepath(self, host, method, path):
         """Search config patterns to find an appropriate file/response to return.
         """
         for x in self.responses:
-            m = re.match(x.pattern, path)
+            m = re.match(x.pattern, host + path)
             if m:
                 data = ""
                 if x.file and x.file != "None":
